#
# spec file for package arm-trusted-firmware-sun50ih6
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define platform sun50i_h6

%global debug_build 1

%bcond_with atf_optee

%if %{with atf_optee}
%define use_optee 1
%if "%{platform}" == "tegra186" || "%{platform}" == "tegra210" || "%{platform}" == "rk3328" || "%{platform}" == "rk3368" || "%{platform}" == "rk3399"
# OP-TEE not available
%define use_optee 0
%endif
%if "%{platform}" == "rpi3"
# Not building
%define use_optee 0
%endif
%if "%{platform}" == "imx8qm" || "%{platform}" == "imx8qx" || "%{platform}" == "sun50i_a64" || "%{platform}" == "sun50i_h6"
# TBD
%define use_optee 0
%endif
%else
%define use_optee 0
%endif

Name:           arm-trusted-firmware-sun50ih6
Version:        2.0
Release:        4.2
%define srcversion 2.0
Summary:        Arm Trusted Firmware-A
License:        BSD-3-Clause
Group:          System/Boot
Url:            https://github.com/ARM-software/arm-trusted-firmware
Source:         https://github.com/ARM-software/arm-trusted-firmware/archive/v%{srcversion}.tar.gz#/arm-trusted-firmware-%{srcversion}.tar.gz
Patch100:       hikey960.diff
#!BuildIgnore: gcc-PIE
%if "%{platform}" == "rpi3"
BuildRequires:  arm-trusted-firmware-rpi3-bootstrap
%endif
%if "%{platform}" == "rk3399"
BuildRequires:  cross-arm-none-gcc%{gcc_version}
%endif
%if "%{platform}" == "hikey"
BuildRequires:  edk2-hikey
%endif
%if "%{platform}" == "hikey960"
BuildRequires:  edk2-hikey960
%endif
BuildRequires:  git
BuildRequires:  libopenssl-devel
%if %{use_optee}
%if "%{platform}" == "qemu"
BuildRequires:  optee-qemu-armv8a
%else
BuildRequires:  optee-%{platform}
%endif
%endif
%if "%{platform}" == "qemu"
BuildRequires:  qemu-uefi-aarch64
%endif
%if "%{platform}" == "hikey"
BuildRequires:  u-boot-hikey
%endif
%if "%{platform}" == "poplar"
BuildRequires:  u-boot-poplar
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
ExclusiveArch:  aarch64

%description
Trusted Firmware-A (TF-A) provides a reference implementation of secure world
software for Armv7-A and Armv8-A, including a Secure Monitor executing at
Exception Level 3 (EL3).

%if "%{platform}" == "poplar"
%package devel
Summary:        ARM Trusted Firmware -- %{platform} development files
Group:          System/Boot
Requires:       %{name} = %{version}

%description devel
ARM Trusted Firmware provides a reference implementation of
secure world software for ARMv8-A, including a Secure Monitor executing at
Exception Level 3 (EL3). It implements various ARM interface standards,
such as the Power State Coordination Interface (PSCI),
Trusted Board Boot Requirements (TBBR, ARM DEN0006C-1) and
SMC Calling Convention. As far as possible the code is designed for reuse
or porting to other ARMv8-A model and hardware platforms.

This sub-package contains development files.
%endif

%prep
%setup -q -n arm-trusted-firmware-%{srcversion}
%patch100 -p1

%build
export BUILD_MESSAGE_TIMESTAMP="\"$(date -d "$(head -n 2 %{_sourcedir}/%{name}.changes | tail -n 1 | cut -d- -f1 )" -u "+%H:%M:%S, %b %e %Y")\""
make %{?_smp_mflags} V=1 DISABLE_PEDANTIC=1 DEBUG=%{debug_build} \
%if "%{platform}" == "tegra186" || "%{platform}" == "tegra210"
%if "%{platform}" == "tegra186"
%define target_soc t186
%endif
%if "%{platform}" == "tegra210"
%define target_soc t210
%endif
     PLAT=tegra TARGET_SOC=%{target_soc} \
%else
     PLAT=%{platform} \
%endif
%if %{use_optee}
     SPD=opteed \
     BL32=/boot/tee-header_v2.bin \
     BL32_EXTRA1=/boot/tee-pager_v2.bin \
     BL32_EXTRA2=/boot/tee-pageable_v2.bin \
%endif
%if "%{platform}" == "hikey"
     SCP_BL2=/boot/mcuimage.bin \
     BL33=/boot/u-boot.bin \
     all fip
%else
%if "%{platform}" == "hikey960"
     SCP_BL2=/boot/lpm3.img \
     BL33=/boot/BL33_AP_UEFI.fd \
     all fip
%else
%if "%{platform}" == "poplar"
     BL33=/boot/u-boot.bin \
     all fip
mv build build.orig
make %{?_smp_mflags} V=1 DISABLE_PEDANTIC=1 DEBUG=%{debug_build} \
     PLAT=poplar POPLAR_RECOVERY=1 \
     BL33=/boot/u-boot.bin \
     all fip
mv build build.recovery
mv build.orig build
%else
%if "%{platform}" == "rpi3"
     BL33=%{_datadir}/arm-trusted-firmware-rpi3-bootstrap/el2-bootstrap.bin \
     all fip
%else
%if "%{platform}" == "qemu"
     BL33=%{_datadir}/qemu/qemu-uefi-aarch64.bin \
     all fip
%else
     all
%endif # qemu
%endif # rpi3
%endif # poplar
%endif # hikey960
%endif # hikey

%install
export NO_BRP_STRIP_DEBUG=true
export NO_DEBUGINFO_STRIP_DEBUG=true

mkdir -p %{buildroot}%{_datadir}/%{name}

%if 0%{?debug_build}
%global dir debug
%else
%global dir release
%endif
%define outdir build/%{platform}/%{dir}
%if "%{platform}" == "tegra186" || "%{platform}" == "tegra210"
%define outdir build/tegra/%{target_soc}/%{dir}
%endif

# u-boot for rockchip requires bl31.elf file
%if "%{platform}" == "rk3328" || "%{platform}" == "rk3368" || "%{platform}" == "rk3399"
install -D -m 0644 %{outdir}/bl31/bl31.elf %{buildroot}%{_datadir}/%{name}/bl31.elf
%else
install -D -m 0644 %{outdir}/bl31.bin %{buildroot}%{_datadir}/%{name}/bl31.bin
%endif

%if "%{platform}" == "hikey" || "%{platform}" == "hikey960" || "%{platform}" == "poplar" || "%{platform}" == "qemu"
install -D -m 0644 %{outdir}/bl1.bin %{buildroot}%{_datadir}/%{name}/bl1.bin
install -D -m 0644 %{outdir}/fip.bin %{buildroot}%{_datadir}/%{name}/fip.bin
%endif
%if "%{platform}" == "hikey" || "%{platform}" == "hikey960"
install -D -m 0644 %{outdir}/bl2.bin %{buildroot}%{_datadir}/%{name}/bl2.bin
%endif
%if "%{platform}" == "poplar"
%define outdir build.recovery/%{platform}/%{dir}
install -D -m 0644 %{outdir}/bl1.bin %{buildroot}%{_datadir}/%{name}/bl1.recovery.bin
install -D -m 0644 %{outdir}/fip.bin %{buildroot}%{_datadir}/%{name}/fip.recovery.bin
mkdir -p %{buildroot}%{_includedir}/%{name}
install -D -m 0644 plat/hisilicon/poplar/include/poplar_layout.h %{buildroot}%{_includedir}/%{name}/
%endif

%files
%defattr(-,root,root)
%license license.rst
%doc acknowledgements.rst contributing.rst maintainers.rst readme.rst dco.txt
%{_datadir}/%{name}

%if "%{platform}" == "poplar"
%files devel
%defattr(-,root,root)
%{_includedir}/%{name}
%endif

%changelog
* Sun Nov 11 2018 afaerber@suse.de
- pre_checkin.sh: Fix package names for sun50i_{a64,h6}
* Sun Nov  4 2018 afaerber@suse.de
- Add imx8qm, imx8qx, sun50i_a64, sun50i_h6
* Sun Nov  4 2018 afaerber@suse.de
- Update to v2.0
  * Drop upstream patches
  arm-trusted-firmware_cve-2018-3639_smccc_rename.patch
  arm-trusted-firmware_cve-2018-3639_smccc_return.patch
  arm-trusted-firmware_cve-2018-3639_rename.patch
  arm-trusted-firmware_cve-2018-3639_static.patch
  arm-trusted-firmware_cve-2018-3639_static_aarch32.patch
  arm-trusted-firmware_cve-2018-3639_dynamic.patch
  * fip_create wrapper is no longer built (use fiptool instead)
  * Set BL33 for qemu
* Sun Jun  3 2018 afaerber@suse.de
- Conditionally enable OP-TEE as BL32
* Sun Jun  3 2018 afaerber@suse.de
- Add rpi3
* Sun Jun  3 2018 afaerber@suse.de
- Set BUILD_MESSAGE_TIMESTAMP for reproducible builds
- Simplify tegra packaging, reusing %%target_soc
* Fri Jun  1 2018 afaerber@suse.de
- Address CVE-2018-3639 (bsc#1085308)
  arm-trusted-firmware_cve-2018-3639_smccc_rename.patch
  arm-trusted-firmware_cve-2018-3639_smccc_return.patch
  arm-trusted-firmware_cve-2018-3639_rename.patch
  arm-trusted-firmware_cve-2018-3639_static.patch
  arm-trusted-firmware_cve-2018-3639_static_aarch32.patch
  arm-trusted-firmware_cve-2018-3639_dynamic.patch
* Thu May 31 2018 afaerber@suse.de
- hikey960.diff: Fix assertion on HiKey 960 (b9o#739)
* Thu May 31 2018 afaerber@suse.de
- Package bl2 for hikey and hikey960
* Mon May 21 2018 afaerber@suse.de
- Add tegra186
* Mon May 21 2018 afaerber@suse.de
- Package poplar_layout.h header for l-loader in devel package
* Sun May 20 2018 afaerber@suse.de
- Build recovery version of poplar, too
* Sun May 20 2018 afaerber@suse.de
- Adopt %%license
- Add poplar
- Prepare tegra186
* Sun May 20 2018 afaerber@suse.de
- Update to v1.5
  * Dropped upstream patches:
  arm-trusted-firmware_pie_1.patch
  arm-trusted-firmware_pie_2.patch
  arm-trusted-firmware_fiptool_pad.patch
  arm-trusted-firmware_fiptool_pad_useafterfree.patch
  arm-trusted-firmware_fiptool_pad_hikey.patch
  arm-trusted-firmware_fiptool_pad_hikey960.patch
  arm-trusted-firmware_cve-2017-5715_a57_a72.patch
  arm-trusted-firmware_cve-2017-5715_a73_a75.patch
  arm-trusted-firmware_cve-2017-5715_pfr0.patch
  arm-trusted-firmware_cve-2017-5715_errata_format.patch
  arm-trusted-firmware_cve-2017-5715_errata_output.patch
  arm-trusted-firmware_cve-2017-5715_platforms.patch
  arm-trusted-firmware_cve-2017-5715_bpiall.patch
  arm-trusted-firmware_cve-2017-5715_smccc.patch
  arm-trusted-firmware_cve-2017-5715_psci.patch
  arm-trusted-firmware_cve-2017-5715_runtime_exceptions.patch
  arm-trusted-firmware_cve-2017-5715_smccc_v1.1.patch
* Sat Feb 10 2018 afaerber@suse.de
- Apply fiptool patches to tools package, too (b9o#633)
- Prepare for detecting PIE support (gh#ARM-software/tf-issues#519)
  arm-trusted-firmware_pie_1.patch
  arm-trusted-firmware_pie_2.patch
* Sat Feb 10 2018 afaerber@suse.de
- Implement SMCCC v1.1 (bsc#1074741)
  arm-trusted-firmware_cve-2017-5715_platforms.patch
  arm-trusted-firmware_cve-2017-5715_bpiall.patch
  arm-trusted-firmware_cve-2017-5715_smccc.patch
  arm-trusted-firmware_cve-2017-5715_psci.patch
  arm-trusted-firmware_cve-2017-5715_runtime_exceptions.patch
  arm-trusted-firmware_cve-2017-5715_smccc_v1.1.patch
* Sat Jan 27 2018 afaerber@suse.de
- Pad HiKey FIP to avoid hanging fastboot transfer (b9o#633)
  arm-trusted-firmware_fiptool_pad.patch
  arm-trusted-firmware_fiptool_pad_useafterfree.patch
  arm-trusted-firmware_fiptool_pad_hikey.patch
  arm-trusted-firmware_fiptool_pad_hikey960.patch
* Sat Jan 27 2018 afaerber@suse.de
- Add CVE-2017-5715 output (bsc#1074741)
  arm-trusted-firmware_cve-2017-5715_errata_format.patch
  arm-trusted-firmware_cve-2017-5715_errata_output.patch
* Mon Jan 22 2018 afaerber@suse.de
- Use debug builds
* Fri Jan 12 2018 afaerber@suse.de
- rk3399: Don't require cross binutils (let cross gcc choose which)
* Fri Jan 12 2018 afaerber@suse.de
- hikey960: Build fip and require EDK2 for SCP_BL2 and BL33
- Refresh CVE-2017-5715 patches (bsc#1074741)
  Drop arm-trusted-firmware_cve-2017-5715_ic_iallu.patch
  Add arm-trusted-firmware_cve-2017-5715_pfr0.patch
- Suppress debuginfo for firmware
* Sun Jan  7 2018 afaerber@suse.de
- Make noarch so that it can be exported
* Sun Jan  7 2018 afaerber@suse.de
- hikey: Build fip and require EDK2 for SCP_BL2
- Add tegra210
* Sun Jan  7 2018 afaerber@suse.de
- Add hikey960
* Sun Jan  7 2018 afaerber@suse.de
- Add hikey
- Clean up pre_checkin.sh
- Don't package bl31.bin for Rockchip, we need bl31.elf only
* Fri Jan  5 2018 afaerber@suse.de
- Require arm-none gcc for RK3399
* Fri Jan  5 2018 afaerber@suse.de
- Address CVE-2017-5715 (bsc#1074741)
  arm-trusted-firmware_cve-2017-5715_a57_a72.patch
  arm-trusted-firmware_cve-2017-5715_a73_a75.patch
  arm-trusted-firmware_cve-2017-5715_ic_iallu.patch
* Wed Jan  3 2018 matwey.kornilov@gmail.com
- Return lost doc files
* Tue Jan  2 2018 matwey.kornilov@gmail.com
- Package bl31.elf
* Tue Jan  2 2018 matwey.kornilov@gmail.com
- acknowledgements.md renamed to acknowledgements.rst
* Thu Dec 28 2017 matwey.kornilov@gmail.com
- Version 1.4
* Mon Dec 26 2016 afaerber@suse.de
- Update to v1.3 final
* Sat Oct  8 2016 afaerber@suse.de
- Initial
